@@ -1,6 +1,7 @@
 # pylint:disable=missing-module-docstring
 from raylab.agents.mapo import MAPOTorchPolicy
 from raylab.policy.losses import ModelEnsembleMLE
+from raylab.policy.losses import SPAML
 
 
 class MlMAPOTorchPolicy(MAPOTorchPolicy):
@@ -10,7 +11,7 @@ class MlMAPOTorchPolicy(MAPOTorchPolicy):
     loss in MAPO.
     """
 
-    # pylint:disable=abstract-method
+    # pylint:disable=too-many-ancestors
 
     @property
     def options(self):
@@ -19,8 +20,21 @@ class MlMAPOTorchPolicy(MAPOTorchPolicy):
 
         return MlMAPOTrainer.options
 
+    @property
+    def model_training_loss(self):
+        return self.loss_mle
+
+    @property
+    def model_warmup_loss(self):
+        return self.loss_mle
+
     def _setup_model_loss(self):
-        self.loss_model = ModelEnsembleMLE(self.module.models)
+        # Placeholder
+        self.loss_paml = SPAML(
+            self.module.models, self.module.actor, self.module.critics
+        )
+
+        self.loss_mle = ModelEnsembleMLE(self.module.models)
 
     def _set_reward_hook(self):
         self.loss_actor.set_reward_fn(self.reward_fn)
