@@ -2,16 +2,11 @@
 import torch.nn as nn
 from gym.spaces import Space
 
-from .ddpg_module import DDPGModule
 from .maxent_model_based import MaxEntModelBased
-from .model_based_ddpg import ModelBasedDDPG
-from .model_based_sac import ModelBasedSAC
-from .naf_module import NAFModule
 from .nfmbrl import NFMBRL
 from .off_policy_nfac import OffPolicyNFAC
 from .on_policy_actor_critic import OnPolicyActorCritic
 from .on_policy_nfac import OnPolicyNFAC
-from .sac_module import SACModule
 from .simple_model_based import SimpleModelBased
 from .svg_module import SVGModule
 from .svg_realnvp_actor import SVGRealNVPActor
@@ -20,14 +15,9 @@ from .trpo_tang2018 import TRPOTang2018
 MODULES = {
     cls.__name__ + "-v0": cls
     for cls in (
-        NAFModule,
-        DDPGModule,
-        SACModule,
         SimpleModelBased,
         SVGModule,
         MaxEntModelBased,
-        ModelBasedDDPG,
-        ModelBasedSAC,
         NFMBRL,
         OnPolicyActorCritic,
         OnPolicyNFAC,
